summaryrefslogtreecommitdiffstats
path: root/layout/mathml/nsMathMLContainerFrame.h
diff options
context:
space:
mode:
Diffstat (limited to 'layout/mathml/nsMathMLContainerFrame.h')
-rw-r--r--layout/mathml/nsMathMLContainerFrame.h15
1 files changed, 6 insertions, 9 deletions
diff --git a/layout/mathml/nsMathMLContainerFrame.h b/layout/mathml/nsMathMLContainerFrame.h
index 805d7e03ca..24bc86c338 100644
--- a/layout/mathml/nsMathMLContainerFrame.h
+++ b/layout/mathml/nsMathMLContainerFrame.h
@@ -37,9 +37,7 @@ class nsMathMLContainerFrame : public nsContainerFrame, public nsMathMLFrame {
public:
nsMathMLContainerFrame(ComputedStyle* aStyle, nsPresContext* aPresContext,
ClassID aID)
- : nsContainerFrame(aStyle, aPresContext, aID),
- mIntrinsicWidth(NS_INTRINSIC_ISIZE_UNKNOWN),
- mBlockStartAscent(0) {}
+ : nsContainerFrame(aStyle, aPresContext, aID) {}
NS_DECL_QUERYFRAME_TARGET(nsMathMLContainerFrame)
NS_DECL_QUERYFRAME
@@ -341,13 +339,13 @@ class nsMathMLContainerFrame : public nsContainerFrame, public nsMathMLFrame {
static void DidReflowChildren(nsIFrame* aFirst, nsIFrame* aStop = nullptr);
/**
* Recompute mIntrinsicWidth if it's not already up to date.
*/
- void UpdateIntrinsicWidth(gfxContext* aRenderingContext);
+ void UpdateIntrinsicISize(gfxContext* aRenderingContext);
- nscoord mIntrinsicWidth;
+ nscoord mIntrinsicISize = NS_INTRINSIC_ISIZE_UNKNOWN;
- nscoord mBlockStartAscent;
+ nscoord mBlockStartAscent = 0;
private:
class RowChildFrameIterator;
@@ -429,8 +427,7 @@ class nsMathMLmathBlockFrame final : public nsBlockFrame {
protected:
explicit nsMathMLmathBlockFrame(ComputedStyle* aStyle,
nsPresContext* aPresContext)
- : nsBlockFrame(aStyle, aPresContext, kClassID) {
- }
+ : nsBlockFrame(aStyle, aPresContext, kClassID) {}
virtual ~nsMathMLmathBlockFrame() = default;
};
@@ -341,13 +339,13 @@ class nsMathMLContainerFrame : public nsContainerFrame, public nsMathMLFrame {
static void DidReflowChildren(nsIFrame* aFirst, nsIFrame* aStop = nullptr);
/**
- * Recompute mIntrinsicWidth if it's not already up to date.
+ * Recompute mIntrinsicISize if it's not already up to date.
*/